/*** COPYRIGHT SECTION ******************************************************
 *  bg_hexdump.c
 *
 *  function used to transform a binary file containning ipmb packets into a 
 *  hexdump file format to used with Wireshark
 *  Output file name is : hexdump_bg
 *  This "hexdump_bg" file will be pass to wireshark "text2pcap" command to 
 *  generate a pcap file format.
 *
 *  for Wireshark - Network traffic analyzer
 *
 *  Copyright (c) 2007 by KONTRON Canada Inc.
 *  chanthy.toeung@ca.kontron.com
 *
 *  Wireshark - Network traffic analyzer
 *  By Gerald Combs <gerald@wireshark.org>
 *  Copyright 1999 Gerald Combs
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
/*=========================================================================
* INCLUDES
*=========================================================================*/
#include <sys/time.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>
#include "bg_ipmipacket.h"

void hexdump_file ( char* fileNameIn, char* fileNameOut )
{
   FILE* pFileRead;
   int i, l;
   time_t curtime;
   char buffer[30];
   pFileRead = fopen( fileNameIn, "r" );
   if( pFileRead == NULL ){
      printf("can't open file %s\n", fileNameIn );
      return;
   }
   else{   
      tIpmb_Header   rqIpmbHeader;
      tIpmbPacket    rqPaquet;
      FILE* hexdumpFile;
      int k, j, pk;
      u08     offset;
      int numBytes = 0;
      pk = 0;
      hexdumpFile = fopen( fileNameOut, "w" );
      i = fread( &rqIpmbHeader, sizeof( rqIpmbHeader ), 1, pFileRead );
      i = fread( &rqPaquet, sizeof( rqPaquet ), 1, pFileRead );
      while( !feof( pFileRead ) ){
         pk++;
         if( ferror( pFileRead ) || ferror(hexdumpFile) ){
            perror("ERROR ");
            break;
         }
         /*Add Timestamp*/
         curtime = rqPaquet.waitTime.tv_sec;
         strftime( buffer, 30, "%m/%d/%y %T.", localtime( &curtime ) );
         fprintf( hexdumpFile, "%s%ld\n", buffer, rqPaquet.waitTime.tv_usec );
         /*group the byte of Netfn and LUN together*/
         rqIpmbHeader.netFn = (rqIpmbHeader.netFn << 2) + rqIpmbHeader.LUN ;
         rqPaquet.rqSeq = (rqPaquet.rqSeq << 2) + rqPaquet.LUN;
         /*calculate the data size*/
         numBytes = rqPaquet.data[0]-8;  /* packet size */
         /*write packet header to file*/
         if( numBytes >= 0 )
            k = fprintf(hexdumpFile, "%08x  %02x", offset, (numBytes+2));
         if( numBytes < 0 ){
               k = fprintf(hexdumpFile, "%08x  %02x %02x %02x  \n",
                        offset, rqPaquet.data[0]-1,
                        rqPaquet.data[numBytes+6], rqIpmbHeader.SlaveAdd);
         }
         else{
            k = fprintf(hexdumpFile, " %02x %02x %02x %02x %02x %02x %02x  \n",
                   rqPaquet.data[numBytes+2], rqIpmbHeader.SlaveAdd,
                   rqIpmbHeader.netFn, rqIpmbHeader.checkSum, rqPaquet.SlaveAdd,
                   rqPaquet.rqSeq, rqPaquet.cmd );
            l = 0;
            offset+= 8;
            k = fprintf(hexdumpFile, "%08x ", offset);
            for( j = 1; j < (numBytes+2); j++){
               k = fprintf(hexdumpFile, " %02x", rqPaquet.data[j]);
               l++;
               if( (l == 8) && (j < (numBytes - 1) ) ){
                  fprintf(hexdumpFile, "  \n" );
                  offset += 8;         	
                  k = fprintf(hexdumpFile, "%08x ", offset);
                  l = 0;
               }
            }
            fprintf(hexdumpFile, "  \n");
         }
         offset = 0;
         i = fread( &rqIpmbHeader, sizeof( rqIpmbHeader ), 1, pFileRead );
         i = fread( &rqPaquet, sizeof( rqPaquet ), 1, pFileRead );
      }
      fclose( hexdumpFile );
      printf("**** Output file name is : %s = %d packets *****\n", fileNameOut, pk);
      fclose( pFileRead );
	}
}
