/*** COPYRIGHT SECTION ******************************************************
 *  bg_ipmipacket.h
 *
 *  Contain ipmb packets structure and function prototype for create ipmb packets
 *  for Wireshark - Network traffic analyzer
 *
 *  Copyright (c) 2007 by KONTRON Canada Inc.
 *  chanthy.toeung@ca.kontron.com
 *
 *  Wireshark - Network traffic analyzer
 *  By Gerald Combs <gerald@wireshark.org>
 *  Copyright 1999 Gerald Combs
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef BG_IPMIPACKET_H
#define BG_IPMIPACKET_H
/*=========================================================================
* INCLUDES
*=========================================================================*/
#include "beagle.h"
#include <sys/time.h>
/*=========================================================================
* CONSTANTS
*=========================================================================*/
#define DATA_SIZE        64

/* maximum waiting time to get the reply after a request is made
*  RQ_TO_RS_TIME ~= 2* TIME_MAX = 700 milliseconds in specification IPMI
*  Read the specifications IPMI v1.0 table 4-1 for more detail
*/
#define DELAY                 0.4  /* 400 milli seconds of delay */
#define RQ_TO_RS_TIME         0.7  /* 700 milli seconds */
#define MATCHED               0    /* matching packet */
#define UN_MATCHED            1    /* non matching packet */
#define INVALID_PACKET_SIZE   100
/*=========================================================================
| GENERAL TYPE DEFINITIONS
 ========================================================================*/
 
/*=========================================================================
*   Packet HEADER of ipmb packet
*=========================================================================*/
struct tIpmb_Header{
   u08 SlaveAdd;     /* slave adresse */
   u08 netFn;       /* NetFn */
   u08 LUN;        /* this can be rqLUN or rsLUN depending on NetFn */
   u08 checkSum;  /* header checksum */
};

typedef struct tIpmb_Header tIpmb_Header;

/*=========================================================================
*   STRUCTURE DE DONN�S DU PAQUET IPMB
*=========================================================================*/
struct tIpmbPacket{
   struct timeval waitTime;
   u08 SlaveAdd;   
   u08 rqSeq;     /* Request sequence */
   u08 LUN;
   u08 cmd;       /* command */
   u08 data[DATA_SIZE]; /* data */  
};

typedef struct tIpmbPacket tIpmbPacket;
/*=========================================================================
* FUNCTIONS
*=========================================================================*/

void fipmipacket(
   char* pFileName
);

void fmatching_packet(
   char* pWriteFileName
);

#endif
