/*** COPYRIGHT SECTION ******************************************************
 *  bg_sniff.h
 *
 *  Header file for bg_sniff.c
 *  for Wireshark - Network traffic analyzer
 *
 *  Copyright (c) 2007 by KONTRON Canada Inc.
 *  chanthy.toeung@ca.kontron.com
 *
 *  Wireshark - Network traffic analyzer
 *  By Gerald Combs <gerald@wireshark.org>
 *  Copyright 1999 Gerald Combs
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef BG_SNIFF_H
#define BG_SNIFF_H

#ifndef STDIN_FILENO
  #define STDIN_FILENO 0
#endif

/*=========================================================================
* INCLUDES
*=========================================================================*/
#include <sys/time.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>
#include <termios.h>
#include <unistd.h>
#include <errno.h>
#include "beagle.h"

/*=========================================================================
* CONSTANTS
*=========================================================================*/
#define MAXIMUM_PORT 8

/*=========================================================================
| MACROS
 ========================================================================*/
/* This will only work for sample rates that
* are multiples of 1MHz.  If any other rates
* are desired, this code needs to be changed.*/
#define TIMESTAMP_TO_NS(stamp, samplerate_khz) \
    (u64)(stamp * (u64)1000 / (u64)(samplerate_khz/1000))

/* The printf format strings are differenct for 64-bit integers
* between Windows and Linux*/
#if defined(WIN32) || defined(_WIN32)
#  define U64_FORMAT_STR "%I64u"
#else
#  define U64_FORMAT_STR "%llu"
#endif

/*=========================================================================
| GENERAL TYPE DEFINITIONS
 ========================================================================*/
extern int errno;
/*=========================================================================
* FUNCTIONS
*=========================================================================*/

void i2cdump (
   int max_bytes,
   int num_packets,
   int num_device,
   Beagle beagle[MAXIMUM_PORT]
);

/*function for get key from keyboard*/
int set_tty_raw(void) ;

int set_tty_cbreak();

int set_tty_cooked();

unsigned char kb_getc(void) ;

unsigned char kb_getc_w(void) ;


#endif
