/*** COPYRIGHT SECTION ******************************************************
 *  display.c
 *
 *  Control the display on standard output according to differents options
 *  given by user.
 *  for Wireshark - Network traffic analyzer
 *
 *  Copyright (c) 2007 by KONTRON Canada Inc.
 *  chanthy.toeung@ca.kontron.com
 *
 *  Wireshark - Network traffic analyzer
 *  By Gerald Combs <gerald@wireshark.org>
 *  Copyright 1999 Gerald Combs
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.

 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.

 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/*===========================================================================
* INCLUDES
*===========================================================================*/
#include <stdio.h>
#include "display.h"

/****************************************************************************
*
* Description  :  print the help of the program
*
* Restriction  :  non
*
* Input        :  non
*
* Output       :  non
*
* Global       :  print out all the usage of the program on standard output
*
* Return       :  non
*
*****************************************************************************/
void usage( void )
{
   printf( "\nGenerate a matching IPMB packet from raw data captured by " );
   printf( "Aardvark device.\n\n" );
   
   printf( " Usage: aasniff [option] <output-filename> <Port-number1> " );
   printf( "(Port-number2)\n\n" );
   
   printf( " Where    <output-filename>  specifies output filename\n" );
   printf( "          <Port-number1>     specifies first port of Aardvark." );
   printf( " Normally this value is 0.\n" );
   printf( "          (Port-number2)     specifies second port of Aardvark.");
   printf( " Normally this value is 1.\n" );
   printf( "                             This port is optional\n\n" );
   
   printf( " Miscellanous:\n" );
   printf( "      -h                     display this help and exit.\n" );
   printf( "      -q                     quiet mod; diplay nothing at all.\n" );
   printf( "      -v <DEBUG_LEVEL>       detail debug of parser states.\n   " );  
   printf( "                          Eg: -v 1  display basic informations.\n" );
   printf( "                             Eg: -v 2  display packets" );
   printf( " informations during matching process.\n       ");
   printf( "                      Eg: -v 3  display all detail informations." );
   printf( "\n\n" );
   printf( " STOP CONDITION:\n");
   printf( "    To stop the program, please press Ctrl+C \n\n" );
}

/****************************************************************************
*
* Description  :  get the option from standard input and treat them
*
* Restriction  :  non
*
* Input        :  argc : number of argument
*                 argv : argument value
*
* Output       :  non
*
* Global       :  
*
* Return       : non
*
*****************************************************************************/
int get_option( int argc, char* argv[] )
{
   char* option;
   option = argv[1];   
   withOption = FALSE;
   quiet = FALSE;
   debug = 0; /*no debug option*/
   normalProcess = FALSE;   
   if( argc < 3 ){
      usage();
      normalProcess = FALSE;
   }
   else{
      if( option[0] == '-'  ){
         withOption = TRUE;
         if( argc == 3 ){
            usage();
            normalProcess = FALSE;
         }
         else{
            switch ( option[1] ){
               case 'q': 
                  printf( "Quiet mode.\n" );
                  quiet = TRUE;
                  normalProcess = TRUE;
                  break;
               case 'h': usage(); break;
               case 'v': printf( "DEBUG mode.\n" );                  
                  normalProcess = TRUE;
                  switch ( argv[2][0] ){
                     case '0': debug = 0; break;
                     case '1':
                        printf( "debug level 1.\n" ); 
                        debug = DEBUG_LEVEL_RAW;
                        break;                     
                     case '2': printf( "debug level 2.\n" ); 
                        debug = DEBUG_LEVEL_PACKET;
                        break;
                     case '3': printf( "debug level 3.\n" ); 
                        debug = DEBUG_LEVEL_ALL;
                        break;
                     default:
                        normalProcess = FALSE;
                        usage();
                        break;   
                 }break;                 
               default:
                  normalProcess = FALSE;      
                  usage();
                  break;
            }
         }
      }
      else{ /* No option is given by user*/
         withOption = FALSE;
         quiet = FALSE;
         debug = 0;
         normalProcess = TRUE;
      }     
   }
   return normalProcess;   
}

int get_debug_level()
{
   return debug;
}

int get_quiet_option()
{
   return quiet;
}

int get_opt()
{
   return withOption;
}
